"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LiquidDocTagCompletionProvider = void 0;
const liquid_html_parser_1 = require("@shopify/liquid-html-parser");
const vscode_languageserver_1 = require("vscode-languageserver");
const liquidDoc_1 = require("../../utils/liquidDoc");
const uri_1 = require("../../utils/uri");
class LiquidDocTagCompletionProvider {
    constructor() { }
    async completions(params) {
        if (!params.completionContext)
            return [];
        if (!(0, uri_1.isSnippet)(params.document.uri))
            return [];
        const { node, ancestors } = params.completionContext;
        const parentNode = ancestors.at(-1);
        if (!node ||
            !parentNode ||
            node.type !== liquid_html_parser_1.NodeTypes.TextNode ||
            parentNode.type !== liquid_html_parser_1.NodeTypes.LiquidRawTag ||
            parentNode.name !== 'doc' ||
            !node.value.startsWith('@')) {
            return [];
        }
        // Need to offset the '@' symbol by 1
        let start = params.document.textDocument.positionAt(node.position.start + 1);
        let end = params.document.textDocument.positionAt(node.position.end);
        return Object.entries(liquidDoc_1.SUPPORTED_LIQUID_DOC_TAG_HANDLES)
            .filter(([label]) => label.startsWith(node.value.slice(1)))
            .map(([label, { description, example, template }]) => ({
            label,
            kind: vscode_languageserver_1.CompletionItemKind.EnumMember,
            documentation: {
                kind: vscode_languageserver_1.MarkupKind.Markdown,
                value: (0, liquidDoc_1.formatLiquidDocTagHandle)(label, description, example),
            },
            textEdit: vscode_languageserver_1.TextEdit.replace(vscode_languageserver_1.Range.create(start, end), template),
            insertTextFormat: vscode_languageserver_1.InsertTextFormat.Snippet,
        }));
    }
}
exports.LiquidDocTagCompletionProvider = LiquidDocTagCompletionProvider;
//# sourceMappingURL=LiquidDocTagCompletionProvider.js.map